<?php
/*
Plugin Name: Automated Editing
Plugin URI: http://wasistlos.waldemarstoffel.com/plugins-fur-wordpress/automated-editing
Description: If working with a lot of editors, who either don't know how to use WP or don't pay attention, this plugin helps you by adding an excerpt automatically to every post, that doesn't have one.
Version: 1.0
Author: Waldemar Stoffel
Author URI: http://www.waldemarstoffel.com
License: GPL3
Text Domain: automated-editing
*/

/*  Copyright 2011  Waldemar Stoffel  (email : w-stoffel@gmx.net)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

/* Stop direct call */

if(preg_match('#' . basename(__FILE__) . '#', $_SERVER['PHP_SELF'])) die("Sorry, you don't have direct aedess to this page.");

/**
 *
 * Additional links in the plugin row
 *
 */
add_filter('plugin_row_meta', 'aed_register_links',10,2);

function aed_register_links($links, $file) {
	
	$base = plugin_basename(__FILE__);
	if ($file == $base) {
		$links[] = '<a href="options-general.php?page=automated-editing-settings">'.__('Settings').'</a>';
		$links[] = '<a href="http://wordpress.org/extend/plugins/automated-editing/faq/" target="_blank">'.__('FAQ').'</a>';
		$links[] = '<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=7RG539AT3TDMA" target="_blank">'.__('Donate').'</a>';
	}
	
	return $links;

}

// import laguage files

load_plugin_textdomain('automated-editing', false , basename(dirname(__FILE__)).'/languages');

// init

add_action('admin_init', 'aed_init');

function aed_init() {
	
	register_setting( 'aed_options', 'aed_options', 'aed_validate' );
	
	add_settings_section('aed_options', __('Styling of the links'), 'aed_display_section', 'aed_excerpt');
	
	add_settings_field('aed_excerpt_length', __('How long should the excerpt be?'), 'aed_excerpt_length_field', 'aed_excerpt', 'aed_options');
	
	add_settings_field('aed_excerpt_style', __('Do you want to count words or sentences?'), 'aed_excerpt_style_field', 'aed_excerpt', 'aed_options');

}

function aed_display_section() {
	
	echo '<p>'.__('Select, how the excerpt should be built by the plugin.').'</p>';

}

function aed_excerpt_length_field() {
	
	$aed_options = get_option('aed_options');
	
	echo '<input id="excerpt_length" name="aed_options[excerpt_length]" type="text" value="'.$aed_options['excerpt_length'].'" />';
	
}

function aed_excerpt_style_field() {
	
	$aed_options = get_option('aed_options');
	
	echo '<select name="aed_options[excerpt_style]" id="excerpt_style">';
    echo '<option value=""></option>';
    echo '<option value="words"';
	if ($aed_options['excerpt_style']=='words') echo ' selected="selected"';
	echo '>'.__('Words').'</option>';
	echo '<option value="sentences"';
	if ($aed_options['excerpt_style']=='sentences') echo ' selected="selected"';
	echo '>'.__('Sentences').'</option>';
    echo '</select>';
	
}

// Cleaning on deactivation

register_deactivation_hook(  __FILE__, 'unset_aed' );

function unset_aed() {
	
	delete_option('aed_options');
	
}

// Installing options page

add_action('admin_menu', 'aed_admin_menu');

function aed_admin_menu() {
	
	add_options_page(__('Automated Editing Settings'), 'Automated Editing', 'administrator', 'automated-editing-settings', 'aed_options_page');
	
}

// Calling the options page

function aed_options_page() {
	
	?>
<div>
  <h2>Automated Editing <?php _e('Settings'); ?></h2>
  <?php _e('How should the excerpt be built?'); ?>
  <p>
    <?php _e('Choose length of it and whether it counts words or sentences.'); ?>
  </p>
  <form action="options.php" method="post">
    <?php
    
	settings_fields('aed_options');
	do_settings_sections('aed_excerpt');
	
	?>
    <input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
  </form>
</div>
<?php
}

function aed_validate($input) {
	
	$newinput['excerpt_length']=trim($input['excerpt_length']);
	
	if (!is_numeric($newinput['excerpt_length'])) $newinput['excerpt_length']='';
	
	$newinput['excerpt_style'] = $input['excerpt_style'];
	
	return $newinput;

}


/**
 *
 * Checking if there is any excerpt; if not, build it
 *
 */
add_action('save_post', 'aed_save_excerpt');

function aed_save_excerpt($post_id) {
	
	if ($_POST['post_type']=='page') return $post_id;
	
	$aed_options = get_option('aed_options');
	
	$aed_excerpt = $_POST['excerpt'];
	
	if (empty($aed_excerpt)) {
		
		$aed_text=str_replace(array("\r\n", "\n", "\r"), '', preg_replace('#\[(.*?)\]#', ' ', $_POST['content']));
		
		$length = (!empty($aed_options['excerpt_length'])) ? $aed_options['excerpt_length'] : 3;
		
		$style = (!empty($aed_options['excerpt_style'])) ? $aed_options['excerpt_style'] : 'sentences';
		
		if ($style == 'words') {
			
			$aed_short=array_slice(explode(' ', $aed_text), 0, $length);
			
			$aed_excerpt=trim(implode(' ', $aed_short));
			
		} else {
		
			$aed_short=array_slice(preg_split("/([\t.!?]+)/", $aed_text, -1, PREG_SPLIT_DELIM_CAPTURE), 0, $length*2);
			
			$aed_excerpt=trim(implode($aed_short));
		
		}
		
	}
	
	$aed_post = array(
					  ID => $post_id,
					  post_excerpt => $aed_excerpt
					  );
	
	remove_action('save_post', 'aed_save_excerpt');
	
	wp_update_post( $aed_post );
	
	add_action('save_post', 'aed_save_excerpt');
	
}

?>